#!/usr/bin/env python3
"""Final test with ChaCha20 removed and larger GSM frames"""

import sys
import time
sys.path.append('UI')
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTimer
from main import PhoneUI

def main():
    app = QApplication(sys.argv)
    window = PhoneUI()
    window.show()
    
    print("\n=== FINAL PROTOCOL TEST ===")
    print("- ChaCha20 removed (using only Noise XK)")
    print("- GSM frame size increased to 10KB\n")
    
    # Click auto test after 1 second
    QTimer.singleShot(1000, lambda: window.auto_test_button.click())
    
    # Final check after 15 seconds
    def final_check():
        phone1 = window.manager.phones[0]
        phone2 = window.manager.phones[1]
        
        console = window.debug_console.toPlainText()
        
        # Count important events
        handshake_complete = console.count("handshake complete!")
        voice_started = console.count("Voice session started")
        decrypt_errors = console.count("Decryption error:")
        voice_decode_errors = console.count("Voice decode error:")
        frames_sent = console.count("voice frame #")
        
        print(f"\nRESULTS:")
        print(f"- Handshakes completed: {handshake_complete}")
        print(f"- Voice sessions started: {voice_started}")
        print(f"- Voice frames sent: {frames_sent}")
        print(f"- Decryption errors: {decrypt_errors}")
        print(f"- Voice decode errors: {voice_decode_errors}")
        
        print(f"\nFINAL STATE:")
        print(f"- Phone 1: handshake={phone1['client'].handshake_complete}, voice={phone1['client'].voice_active}")
        print(f"- Phone 2: handshake={phone2['client'].handshake_complete}, voice={phone2['client'].voice_active}")
        print(f"- Frames sent: P1={phone1.get('frame_counter', 0)}, P2={phone2.get('frame_counter', 0)}")
        print(f"- Frames received: P1={phone1['client'].voice_frame_counter}, P2={phone2['client'].voice_frame_counter}")
        
        # Success criteria
        if (handshake_complete >= 2 and 
            voice_started >= 2 and 
            decrypt_errors == 0 and
            phone1['client'].voice_frame_counter > 0 and
            phone2['client'].voice_frame_counter > 0):
            print("\n✅ SUCCESS! Full protocol stack working!")
            print("   - Noise XK handshake ✓")
            print("   - Voice codec (Codec2) ✓")
            print("   - 4FSK modulation ✓")
            print("   - Bidirectional voice ✓")
        else:
            print("\n❌ Protocol test failed")
            if decrypt_errors > 0:
                print("   - Still getting decryption errors")
            if phone1['client'].voice_frame_counter == 0:
                print("   - Phone 1 not receiving voice")
            if phone2['client'].voice_frame_counter == 0:
                print("   - Phone 2 not receiving voice")
        
        app.quit()
    
    QTimer.singleShot(15000, final_check)
    
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()