#!/usr/bin/env python3
"""Test with voice decode fix"""

import sys
import time
sys.path.append('UI')
from PyQt5.QtWidgets import QApplication
from PyQt5.QtCore import QTimer
from main import PhoneUI

def main():
    app = QApplication(sys.argv)
    window = PhoneUI()
    
    # Track results
    results = {
        'decode_errors': 0,
        'frames_decoded': 0
    }
    
    original_debug = window.debug
    def track_debug(msg):
        if "Voice decode error:" in msg:
            results['decode_errors'] += 1
            original_debug(msg)  # Show the error
        elif "Received voice data frame" in msg:
            results['frames_decoded'] += 1
            if results['frames_decoded'] == 1:
                original_debug("First voice frame successfully received!")
    
    window.debug = track_debug
    window.show()
    
    print("\n=== VOICE DECODE FIX TEST ===\n")
    
    # Simple test sequence
    def start_test():
        print("1. Making call...")
        window.manager.phone_action(0, window)
        QTimer.singleShot(1000, answer_call)
    
    def answer_call():
        print("2. Answering call...")
        window.manager.phone_action(1, window)
        QTimer.singleShot(5000, show_results)
    
    def show_results():
        print(f"\n3. Results after 5 seconds:")
        print(f"   Decode errors: {results['decode_errors']}")
        print(f"   Frames decoded: {results['frames_decoded']}")
        
        if results['decode_errors'] == 0 and results['frames_decoded'] > 0:
            print(f"\n✅ Voice decode fixed! No more 'bytes' object errors.")
        else:
            print(f"\n❌ Still having issues with voice decode")
        
        app.quit()
    
    QTimer.singleShot(1000, start_test)
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()